@@ -16,12 +16,10 @@ CHANGELOG=`dirname $0`/debian/changelog
 
 case "$1" in
     maemo5)
-    CFLAGS="-O2 -pipe -mcpu=cortex-a8"
     VERSION_SUFFIX=-m5
     cp debian/control.m5 debian/control
     ;;
     OS2008|maemo4)
-    CFLAGS="-O2 -pipe -mcpu=arm1136jf-s"
     VERSION_SUFFIX=-OS2008
     cp debian/control.m4 debian/control
     ;;
