@@ -48,6 +48,7 @@
 #include "settings.h"
 #include "gps.h"
 #include "map.h"
+#include "map-download.h"
 #include "mapper-types.h"
 #include "ui-common.h"
 #include "db.h"
@@ -59,6 +60,7 @@
 #include "search.h"
 #include "dialogs.h"
 #include "filter-gui.h"
+#include "import-gui.h"
 #include "map-repo.h"
 #include "config-gconf.h"
 #include "settings-gui.h"
@@ -152,7 +154,7 @@ return TRUE;
 gboolean 
 menu_cb_track_save(GtkAction * action)
 {
-track_save();
+track_save(_track);
 path_tree_view_update_store(mapp.track_tree_view, _track);
 return TRUE;
 }
@@ -160,7 +162,7 @@ return TRUE;
 gboolean 
 menu_cb_track_insert_break(GtkAction * action)
 {
-track_insert_break();
+track_insert_break(_track);
 path_tree_view_update_store(mapp.track_tree_view, _track);
 return TRUE;
 }
@@ -168,7 +170,7 @@ return TRUE;
 gboolean 
 menu_cb_track_insert_mark(GtkAction * action)
 {
-if (track_insert_mark()) {
+if (track_insert_mark(_track)) {
 	map_render_paths();
 	MACRO_QUEUE_DRAW_AREA();
 	path_tree_view_update_store(mapp.track_tree_view, _track);
@@ -179,21 +181,21 @@ return TRUE;
 gboolean 
 menu_cb_track_distlast(GtkAction * action)
 {
-track_show_distance_from_last();
+track_show_distance_from_last(_track);
 return TRUE;
 }
 
 gboolean 
 menu_cb_track_distfirst(GtkAction * action)
 {
-track_show_distance_from_first();
+track_show_distance_from_first(_track);
 return TRUE;
 }
 
 gboolean 
 menu_cb_track_clear(GtkAction * action)
 {
-track_clear();
+track_clear(_track);
 path_tree_view_update_store(mapp.track_tree_view, _track);
 return TRUE;
 }
@@ -509,8 +511,6 @@ set_action_sensitive("autocenter_lead", _enable_gps);
 
 if (_enable_gps==FALSE)
 	set_action_activate("autocenter_none", TRUE);
-else
-	gps_info_clear();
 
 map_move_mark();
 
@@ -724,13 +724,13 @@ switch (event->keyval) {
 		route_show_distance_to_last();
 	break;
 	case CUSTOM_ACTION_TRACK_BREAK:
-		track_insert_break();
+		track_insert_break(_track);
 	break;
 	case CUSTOM_ACTION_TRACK_DISTLAST:
-		track_show_distance_from_last();
+		track_show_distance_from_last(_track);
 	break;
 	case CUSTOM_ACTION_TRACK_DISTFIRST:
-		track_show_distance_from_first();
+		track_show_distance_from_first(_track);
 	break;
 	case CUSTOM_ACTION_TOGGLE_GPS:
 		set_action_activate("gps_enable", !_enable_gps);
@@ -1108,7 +1108,7 @@ cmenu_cb_way_show_latlon(GtkAction * action)
 {
 WayPoint *way;
 
-if ((way=find_nearest_waypoint(x2unit(_cmenu_position_x), y2unit(_cmenu_position_y))))
+if ((way=route_find_nearest_waypoint(x2unit(_cmenu_position_x), y2unit(_cmenu_position_y))))
 		cmenu_show_latlon(way->point->unitx, way->point->unity);
 
 return TRUE;
@@ -1119,7 +1119,7 @@ cmenu_cb_way_show_desc(GtkAction * action)
 {
 WayPoint *way;
 
-if ((way=find_nearest_waypoint(x2unit(_cmenu_position_x), y2unit(_cmenu_position_y)))) {
+if ((way=route_find_nearest_waypoint(x2unit(_cmenu_position_x), y2unit(_cmenu_position_y)))) {
 	MACRO_BANNER_SHOW_INFO(mapp.mainwindow, way->desc);
 }
 
@@ -1131,7 +1131,7 @@ cmenu_cb_way_clip_latlon(GtkAction * action)
 {
 WayPoint *way;
 
-if ((way=find_nearest_waypoint(x2unit(_cmenu_position_x), y2unit(_cmenu_position_y))))
+if ((way=route_find_nearest_waypoint(x2unit(_cmenu_position_x), y2unit(_cmenu_position_y))))
 		cmenu_clip_latlon(way->point->unitx, way->point->unity);
 return TRUE;
 }
@@ -1141,7 +1141,7 @@ cmenu_cb_way_clip_desc(GtkAction * action)
 {
 WayPoint *way;
 
-if ((way=find_nearest_waypoint(x2unit(_cmenu_position_x), y2unit(_cmenu_position_y))))
+if ((way=route_find_nearest_waypoint(x2unit(_cmenu_position_x), y2unit(_cmenu_position_y))))
 	gtk_clipboard_set_text(gtk_clipboard_get(GDK_SELECTION_CLIPBOARD), way->desc, -1);
 
 return TRUE;
@@ -1152,7 +1152,7 @@ cmenu_cb_way_route_to(GtkAction * action)
 {
 WayPoint *way;
 
-if ((way=find_nearest_waypoint(x2unit(_cmenu_position_x), y2unit(_cmenu_position_y))))
+if ((way=route_find_nearest_waypoint(x2unit(_cmenu_position_x), y2unit(_cmenu_position_y))))
 	cmenu_route_to(way->point->unitx, way->point->unity);
 
 return TRUE;
@@ -1163,7 +1163,7 @@ cmenu_cb_way_distance_to(GtkAction * action)
 {
 WayPoint *way;
 
-if ((way=find_nearest_waypoint(x2unit(_cmenu_position_x), y2unit(_cmenu_position_y))))
+if ((way=route_find_nearest_waypoint(x2unit(_cmenu_position_x), y2unit(_cmenu_position_y))))
 	route_show_distance_to(way->point);
 
 return TRUE;
@@ -1174,7 +1174,7 @@ cmenu_cb_way_delete(GtkAction * action)
 {
 WayPoint *way;
 
-if ((way=find_nearest_waypoint(x2unit(_cmenu_position_x), y2unit(_cmenu_position_y)))) {
+if ((way=route_find_nearest_waypoint(x2unit(_cmenu_position_x), y2unit(_cmenu_position_y)))) {
 	gchar buffer[BUFFER_SIZE];
 	GtkWidget *confirm;
 
@@ -1250,7 +1250,7 @@ cmenu_cb_way_add_poi(GtkAction * action)
 {
 WayPoint *way;
 
-if ((way=find_nearest_waypoint(x2unit(_cmenu_position_x), y2unit(_cmenu_position_y)))) {
+if ((way=route_find_nearest_waypoint(x2unit(_cmenu_position_x), y2unit(_cmenu_position_y)))) {
 	poi_info *p;
 
 	p=poi_new();
@@ -1368,7 +1368,7 @@ static guint m=0;
 g_debug("Headset btn");
 switch (hb_action) {
 case 1:
-	d=dicto_widget_get_dicto(mapp.audio_ui);
+	d=dicto_widget_get_dicto(DICTO_WIDGET(mapp.audio_ui));
 	f=dicto_filename_time_new(d, 0);
 	dicto_toggle_record(d, f);
 	g_free(f);
