@@ -134,7 +134,7 @@ return gps;
 void
 gps_clear(Gps *gps)
 {
-gdouble olat=0, olon=0;
+gdouble olat=0.0, olon=0.0;
 
 g_return_if_fail(gps);
 gps->io.fd=-1;
@@ -427,6 +427,8 @@ switch (gps->io.type) {
 }
 
 gps_clear(gps);
+if (gps->update_info)
+	g_idle_add((GSourceFunc)gps->update_info, gps);
 }
 
 static void
