@@ -63,6 +63,7 @@
 #include "announcements.h"
 #include "gtkcompass.h"
 #include "dialogs.h"
+#include "cb.h"
 
 #define DEBUG_MAP_TIME 1
 
@@ -106,6 +107,8 @@ static guint buf_height_pixels=BUF_HEIGHT_PIXELS;
 /** The backing pixmap of map_widget. */
 static GdkPixmap *map_pixmap;
 
+static ImageCache *map_icon_ic;
+
 /* Tile cache, this might need some adjustment */
 #define MAP_CACHE_MAX (48)
 
@@ -194,6 +197,7 @@ map_widget=gtk_drawing_area_new();
 map_timer=g_timer_new();
 
 map_ic=image_cache_new(MAP_CACHE_MAX, FALSE);
+map_icon_ic=image_cache_new(MAP_CACHE_MAX, FALSE);
 
 map_poi_id=0;
 g_signal_connect_after(G_OBJECT(map_widget), "realize", G_CALLBACK(map_cb_after_realize), NULL);
@@ -331,8 +335,17 @@ gdk_draw_arc(mapp.map_widget->window,
 	2 * _draw_width,
 	2 * _draw_width,
 	0, 360 * 64);
+gdk_draw_arc(mapp.map_widget->window, _gc[COLORABLE_MARK],
+	TRUE,
+	mark_x1 - _draw_width/2,
+	mark_y1 - _draw_width/2,
+	_draw_width,
+	_draw_width,
+	0, 360 * 64);
+if (!_show_velvec)
+	return;
 gdk_draw_line(mapp.map_widget->window,
-	gps->io.conn==RCVR_FIXED ? (_show_velvec ? _gc[COLORABLE_MARK_VELOCITY] : _gc[COLORABLE_MARK]) : _gc[COLORABLE_MARK_OLD],
+	gps->io.conn==RCVR_FIXED ? _gc[COLORABLE_MARK_VELOCITY] : _gc[COLORABLE_MARK_OLD],
 	mark_x1,
 	mark_y1,
 	mark_x2,
@@ -588,7 +601,10 @@ map_render_data(void)
 if (!GTK_WIDGET_MAPPED(mapp.map_widget))
 	return;
 
-if (_show_poi && map_drag_id==0 && _zoom<10)
+if(_show_tracks>0 && map_drag_id==0 && _zoom<12)
+	map_render_paths();
+
+if (_show_poi && map_drag_id==0 && _zoom<10 && _poi_zoom > _zoom)
 	map_render_all_pois(buf_width_pixels, buf_height_pixels);
 
 if (_home.valid)
@@ -597,9 +613,6 @@ if (_home.valid)
 if (_dest.valid)
 	map_draw_position_icon(&_dest, "destination");
 
-if(_show_tracks>0 && map_drag_id==0 && _zoom<12)
-	map_render_paths();
-
 MACRO_QUEUE_DRAW_AREA();
 }
 
@@ -928,13 +941,17 @@ if ((x < 0) || (y < 0))
 if ((x > buf_width_pixels) || (y > buf_height_pixels))
 	return;
 
-g_snprintf(buffer, sizeof(buffer), "%s/pixmaps/mapper/%s.png", DATADIR, icon);
-p=gdk_pixbuf_new_from_file(buffer, NULL);
-if (!p)
-	return;
+p=image_cache_get(map_icon_ic, icon);
+if (!p) {
+	g_snprintf(buffer, sizeof(buffer), "%s/pixmaps/mapper/%s.png", DATADIR, icon);
+	p=gdk_pixbuf_new_from_file(buffer, NULL);
+	if (!p)
+		return;
+	g_object_ref(p);
+	image_cache_put(map_icon_ic, icon, p, NULL);
+}
 
 map_draw_pixbuf_on_buffer(x, y, p);
-g_object_unref(p);
 }
 
 /**
@@ -978,9 +995,10 @@ if (!unity1) {
 	y2 = unit2bufy(unity2);
 	/* Make sure this circle will be visible. */
 	if ((x2 < buf_width_pixels) && (y2 < buf_height_pixels))
-		gdk_draw_arc(map_pixmap, gc_alt, FALSE,	/* FALSE: not filled. */
-		     x2 - _draw_width, y2 - _draw_width, 2 * _draw_width, 2 * _draw_width, 0,	/* start at 0 degrees. */
-		     360 * 64);
+		gdk_draw_arc(map_pixmap, gc_alt, FALSE,
+			x2 - _draw_width, y2 - _draw_width,
+			2 * _draw_width, 2 * _draw_width,
+			0, 360 * 64);
 } else if (!unity2) {
 	guint x1, y1;
 
@@ -988,9 +1006,10 @@ if (!unity1) {
 	y1 = unit2bufy(unity1);
 	/* Make sure this circle will be visible. */
 	if ((x1 < buf_width_pixels) && ((unsigned)y1 < buf_height_pixels))
-		gdk_draw_arc(map_pixmap, gc_alt, FALSE,	/* FALSE: not filled. */
-		     x1 - _draw_width, y1 - _draw_width, 2 * _draw_width, 2 * _draw_width, 0,	/* start at 0 degrees. */
-		     360 * 64);
+		gdk_draw_arc(map_pixmap, gc_alt, FALSE,
+			x1 - _draw_width, y1 - _draw_width,
+			2 * _draw_width, 2 * _draw_width,
+			0, 360 * 64);
 } else {
 	gint x1, y1, x2, y2;
 
@@ -1062,9 +1081,10 @@ if ((_show_tracks & ROUTES_MASK) && _route->head != _route->tail) {
 
 		if ((x1 < buf_width_pixels) && (y1 < buf_height_pixels)) {
 			/* Draw the next waypoint as a break. */
-			gdk_draw_arc(map_pixmap, _gc[COLORABLE_ROUTE_BREAK], FALSE,	/* FALSE: not filled. */
-			     x1 - _draw_width, y1 - _draw_width, 4 * _draw_width, 4 * _draw_width, 0,	/* start at 0 degrees. */
-			     360 * 64);
+			gdk_draw_arc(map_pixmap, _gc[COLORABLE_ROUTE_BREAK], FALSE,
+				x1 - _draw_width, y1 - _draw_width,
+				2 * _draw_width, 2 * _draw_width,
+				0, 360 * 64);
 		}
 	}
 }
@@ -1089,6 +1109,10 @@ if (!(event->state & GDK_BUTTON1_MASK)) {
 	return TRUE;
 }
 
+map_dragged++;
+if (map_dragged<16)
+	return FALSE;
+
 if (event->is_hint) {
 	gdk_window_get_pointer(event->window, &xx, &yy, &state);
 	state = event->state;
@@ -1108,7 +1132,6 @@ nunity=y2unit((gint) (cy - (yy - before[1])));
 
 map_center_unit(nunitx, nunity);
 
-map_dragged++;
 before[0] = xx;
 before[1] = yy;
 return FALSE;
@@ -1473,7 +1496,10 @@ gdouble dh=0.0;
 gdouble dt, cdist, wdist;
 static gdouble prev_dt=99999.0;
 static gboolean dest_reached=FALSE;
-gchar buffer[128];
+gchar buffer[64], buffer2[16];
+
+buffer[0]=0;
+buffer2[0]=0;
 
 if (_dest.valid) {
 	dt=calculate_distance(lat, lon, _dest.lat, _dest.lon);
@@ -1498,11 +1524,8 @@ if (_dest.valid) {
 } else {
 	dest_reached=FALSE;
 	prev_dt=99999.0;
-	buffer[0]=0;
 }
 
-gtk_compass_set_dest_heading(mapp.tab_compass, _dest.valid, (gfloat)dh);
-
 if (_next_way && _next_way->point) {
 	gdouble wp_lat, wp_lon;
 	gfloat wc;
@@ -1510,22 +1533,19 @@ if (_next_way && _next_way->point) {
 	unit2latlon(_next_way->point->unitx,_next_way->point->unity, wp_lat, wp_lon);
 	wc=calculate_course(lat, lon, wp_lat, wp_lon);
 	gtk_compass_set_way_heading(mapp.tab_compass, TRUE, wc);
-
 	wdist=route_get_distance_to(_next_way->point) * UNITS_CONVERT[_units];
+	g_snprintf(buffer, sizeof(buffer), "W: %.02f %s", wdist, UNITS_TEXT[_units]);
+	g_snprintf(buffer2, sizeof(buffer2), "%0.02f", wc<0 ? 360+wc : wc);
 } else {
 	gtk_compass_set_way_heading(mapp.tab_compass, FALSE, 0);
+	if (_dest.valid && !_next_way) {
+		g_snprintf(buffer, sizeof(buffer), "D: %.02f %s", cdist, UNITS_TEXT[_units]);
+		g_snprintf(buffer2, sizeof(buffer2), "%0.02f", dh<0 ? 360+dh : dh);
+	}
 }
-
-if (_dest.valid && _next_way && _next_way->point)
-	g_snprintf(buffer, sizeof(buffer), "W: %.02f %s (%.02f %s)", wdist, UNITS_TEXT[_units], cdist, UNITS_TEXT[_units]);
-else if (_dest.valid && !_next_way)
-	g_snprintf(buffer, sizeof(buffer), "%.02f %s (%0.02f)", cdist, UNITS_TEXT[_units], dh<0 ? 360+dh : dh);
-else if (!_dest.valid)
-	g_snprintf(buffer, sizeof(buffer), _("N/A"));
-else
-	g_snprintf(buffer, sizeof(buffer), " ");
-
+gtk_compass_set_dest_heading(mapp.tab_compass, _dest.valid, (gfloat)dh);
 gtk_label_set_label(GTK_LABEL(mapp.ib.distance), buffer);
+gtk_label_set_label(GTK_LABEL(mapp.ib.direction), buffer);
 }
 
 static gboolean
@@ -1591,10 +1611,10 @@ map_cb_scroll_event(GtkWidget * widget, GdkEventScroll * event)
 {
 if (event->direction == GDK_SCROLL_UP) {
 	map_center_unit(x2unit((gint) (event->x + 0.5)), y2unit((gint) (event->y + 0.5)));
-	map_set_zoom(_zoom - 1);
+	map_zoom_in();
 } else if (event->direction == GDK_SCROLL_DOWN) {
 	map_center_unit(x2unit((gint) (event->x + 0.5)), y2unit((gint) (event->y + 0.5)));
-	map_set_zoom(_zoom + 1);
+	map_zoom_out();
 }
 return FALSE;
 }
@@ -1616,6 +1636,25 @@ map_dragged=0;
 map_drag_id=g_signal_connect(G_OBJECT(mapp.map_widget), "motion_notify_event", G_CALLBACK(map_follow_move_cb), NULL);
 }
 
+void
+map_menu_check_context(void)
+{
+guint ux, uy;
+
+ux=x2unit(_cmenu_position_x);
+uy=y2unit(_cmenu_position_y);
+if (map_poi_find_at_map_xy(_cmenu_position_x, _cmenu_position_y, _zoom<2 ? 32 : 16, &map_poi_id)==TRUE) {
+	gtk_widget_show(_cmenu_poi);
+} else {
+	gtk_widget_hide(_cmenu_poi);
+}
+if (route_find_nearest_waypoint(ux, uy)) {
+	gtk_widget_show(_cmenu_way);
+} else {
+	gtk_widget_hide(_cmenu_way);
+}
+}
+
 /**
  * Stop map drag operation
  */
@@ -1697,8 +1736,9 @@ case 1:
 			_gps->data.lon=lon;
 			_gps->data.speed=0;
 			map_draw_track(ux, uy);
+			track_add(&_gps->data);
 			track_add(NULL);
-			route_update_nears(FALSE);
+			/* route_update_nears(FALSE); */
 		}
 		/* Fake drag so we don't popup POIs when doubleclicking */
 		map_dragged=666;
@@ -1720,11 +1760,6 @@ case 2:
 break;
 case 3:
 #ifndef WITH_HILDON
-	if (map_poi_find_at_map_xy(_cmenu_position_x, _cmenu_position_y, _zoom<2 ? 32 : 16, &map_poi_id)==TRUE) {
-		gtk_widget_show(_cmenu_poi);
-	} else {
-		gtk_widget_hide(_cmenu_poi);
-	}
 	gtk_menu_popup(GTK_MENU(_menu_map), NULL, NULL, NULL, NULL, event->button, gtk_get_current_event_time());
 #endif
 break;
@@ -1758,7 +1793,7 @@ case 1:
 	ux=x2unit(_cmenu_position_x);
 	uy=y2unit(_cmenu_position_y);
 
-	if (map_dragged<=8) {
+	if (map_dragged<=16) {
 		if (map_poi_find_at_map_xy(_cmenu_position_x, _cmenu_position_y, 32, &map_poi_id)==TRUE)
 			map_show_poi_menu(map_poi_id);
 	} else {
