@@ -807,6 +807,8 @@ if (p->url)
 	WRITE_HTML("<tr><th align=\"left\">Link:</th><td><a href=\"%s\">Web site</a></td></tr>", p->url);
 if (p->desc)
 	WRITE_HTML("<tr><th align=\"left\" colspan=\"2\">Description:</th><td colspan=\"2\">%s</td></tr>", p->desc);
+if (p->osm_id>0)
+	WRITE_HTML("<tr><th align=\"left\">OSM:</th><td><a href=\"http://www.openstreetmap.org/browse/node/%u\">View/Edit on OpenStreetMap.org</a></td></tr>", p->osm_id);
 if (ls>0) {
 	gchar *elabel;
 
