@@ -55,9 +55,6 @@
    ((guint64)((((gint64)(b).unitx)-(a).unitx)*(((gint64)(b).unitx)-(a).unitx))\
   + (guint64)((((gint64)(b).unity)-(a).unity)*(((gint64)(b).unity)-(a).unity)))
 
-#define WPT_ANNOUNCED 	(1 << 1)
-/* #define WPT_NONAME	(1 << 2) */
-
 static gboolean show_directions=TRUE;
 
 typedef struct _OriginToggleInfo OriginToggleInfo;
@@ -99,22 +96,28 @@ gtk_widget_destroy(confirm);
 void
 route_check_waypoint_announce(GpsData *gps)
 {
-guint announce_thres_unsquared;
+guint an_wpt_now, an_wpt_msg;
 
 if (!gps || !_announce_waypoints || !_next_way)
 	return;
 
-if (_next_way->flags & WPT_ANNOUNCED)
+if (_next_way->flags>=2)
 	return;
 
+an_wpt_msg=(20+(guint)gps->speed)*_announce_notice_ratio*3;
+an_wpt_now=(2+(guint)gps->speed)*_announce_notice_ratio;
 
-announce_thres_unsquared=(20+(guint)gps->speed)*_announce_notice_ratio*3;
-
-if (_next_way_dist_squared > (announce_thres_unsquared * announce_thres_unsquared))
+if (_next_way_dist_squared > (an_wpt_msg * an_wpt_msg))
 	return;
 
-_next_way->flags|=WPT_ANNOUNCED;
-announce_waypoint(_next_way->desc);
+if (_next_way_dist_squared < (an_wpt_now*an_wpt_now) && _next_way->flags < 2) {
+	_next_way->flags=2;
+	announce_waypoint(_next_way);
+} else if (_next_way_dist_squared < (an_wpt_msg*an_wpt_msg) && _next_way->flags==0) {
+	_next_way->flags=1;
+	announce_waypoint(_next_way);
+}
+mapper_info_banner_set_waypoint_direction(_next_way);
 }
 
 /**
@@ -135,7 +138,7 @@ gboolean
 route_open_file(void)
 {
 gchar *buffer;
-gint size;
+guint size;
 
 if (file_open_get_contents(&_route_dir_uri, &buffer, &size)) {
 	/* If auto is enabled, append the route, otherwise replace it. */
@@ -504,7 +507,7 @@ return ret;
 }
 
 WayPoint *
-find_nearest_waypoint(guint unitx, guint unity)
+route_find_nearest_waypoint(guint unitx, guint unity)
 {
 WayPoint *wcurr;
 WayPoint *wnear;
