@@ -547,19 +547,22 @@ gtk_widget_set_sensitive(_cmenu_poi, _db != NULL);
 return TRUE;
 }
 
+gboolean
+settings_dialog_speech_test_cb(GtkWidget *widget, gpointer data)
+{
+speak_text("Welcome to Mapper! This is test. 1 2 3.");
+return TRUE;
+}
+
 /**
  * Bring up the Settings dialog.
  */
 gboolean 
-settings_dialog()
+settings_dialog(void)
 {
 GtkWidget *dialog;
 GtkWidget *notebook;
-GtkWidget *table;
-GtkWidget *hbox;
-GtkWidget *vbox;
-GtkWidget *hbox2;
-GtkWidget *label;
+GtkWidget *table, *hbox, *vbox, *label;
 GtkWidget *num_center_ratio;
 GtkWidget *num_lead_ratio;
 GtkWidget *num_announce_notice;
@@ -568,6 +571,7 @@ GtkWidget *num_voice_speed;
 GtkWidget *num_voice_pitch;
 GtkWidget *lbl_voice_speed;
 GtkWidget *lbl_voice_pitch;
+GtkWidget *btn_speech_test;
 GtkWidget *num_draw_width;
 GtkWidget *chk_always_keep_on;
 GtkWidget *cmb_units;
@@ -576,7 +580,6 @@ GtkWidget *num_poi_zoom;
 GtkWidget *chk_speed_on;
 GtkWidget *num_speed;
 GtkWidget *cmb_info_font_size;
-
 GtkWidget *announce_destination;
 GtkWidget *announce_overspeed;
 GtkWidget *announce_waypoints;
@@ -621,20 +624,23 @@ gtk_box_pack_start(GTK_BOX(vbox), announce_destination=gtk_check_button_new_with
 gtk_box_pack_start(GTK_BOX(vbox), announce_overspeed=gtk_check_button_new_with_label(_("Enable overspeed announcements")), TRUE, TRUE, 4);
 
 /* Voice page */
-gtk_notebook_append_page(GTK_NOTEBOOK(notebook), table=gtk_table_new(2, 3, FALSE), label=gtk_label_new(_("Voice")));
+gtk_notebook_append_page(GTK_NOTEBOOK(notebook), vbox=gtk_vbox_new(FALSE, 2), label=gtk_label_new(_("Voice")));
 
 /* Enable Voice. */
-gtk_table_attach(GTK_TABLE(table), chk_enable_voice=gtk_check_button_new_with_label(_("Enable Voice Synthesis")), 0, 2, 1, 2, GTK_EXPAND | GTK_FILL, 0, 2, 4);
+gtk_box_pack_start(GTK_BOX(vbox), chk_enable_voice=gtk_check_button_new_with_label(_("Enable Voice Synthesis")), TRUE, TRUE, 4);
 gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(chk_enable_voice), _enable_voice);
 
 /* Voice Speed and Pitch. */
-gtk_table_attach(GTK_TABLE(table), hbox=gtk_hbox_new(FALSE, 4), 0, 2, 2, 3, GTK_EXPAND | GTK_FILL, 0, 2, 6);
-gtk_box_pack_start(GTK_BOX(hbox), hbox2=gtk_hbox_new(FALSE, 4), TRUE, TRUE, 4);
-gtk_box_pack_start(GTK_BOX(hbox2), lbl_voice_speed=gtk_label_new(_("Speed (words/minute)")), TRUE, TRUE, 0);
-gtk_box_pack_start(GTK_BOX(hbox2), num_voice_speed=hildon_number_editor_new(80, 370), TRUE, TRUE, 0);
-gtk_box_pack_start(GTK_BOX(hbox), hbox2=gtk_hbox_new(FALSE, 4), TRUE, TRUE, 4);
-gtk_box_pack_start(GTK_BOX(hbox2), lbl_voice_pitch=gtk_label_new(_("Pitch")), TRUE, TRUE, 0);
-gtk_box_pack_start(GTK_BOX(hbox2), num_voice_pitch=hildon_number_editor_new(1, 99), TRUE, TRUE, 0);
+gtk_box_pack_start(GTK_BOX(vbox), hbox=gtk_hbox_new(FALSE, 4), TRUE, TRUE, 4);
+gtk_box_pack_start(GTK_BOX(hbox), lbl_voice_speed=gtk_label_new(_("Speed (words/minute)")), FALSE, TRUE, 0);
+gtk_box_pack_start(GTK_BOX(hbox), num_voice_speed=hildon_number_editor_new(80, 370), TRUE, TRUE, 0);
+
+gtk_box_pack_start(GTK_BOX(vbox), hbox=gtk_hbox_new(FALSE, 4), TRUE, TRUE, 4);
+gtk_box_pack_start(GTK_BOX(hbox), lbl_voice_pitch=gtk_label_new(_("Pitch")), FALSE, TRUE, 0);
+gtk_box_pack_start(GTK_BOX(hbox), num_voice_pitch=hildon_number_editor_new(1, 99), TRUE, TRUE, 0);
+
+gtk_box_pack_start(GTK_BOX(vbox), btn_speech_test=gtk_button_new_with_label(_("Test")), FALSE, TRUE, 0);
+g_signal_connect(G_OBJECT(btn_speech_test), "clicked", G_CALLBACK(settings_dialog_speech_test_cb), NULL);
 
 /* Display settings page. */
 gtk_notebook_append_page(GTK_NOTEBOOK(notebook), table=gtk_table_new(2, 3, FALSE), label=gtk_label_new(_("Display")));
@@ -735,6 +741,8 @@ if (GTK_RESPONSE_ACCEPT == gtk_dialog_run(GTK_DIALOG(dialog))) {
 	speak_set_parameters(_voice_speed, _voice_pitch);
 	update_gcs();
 	config_save();
+} else {
+
 }
 
 #ifndef WITH_HILDON
