@@ -4,6 +4,8 @@
 gboolean settings_dialog(void);
 gboolean settings_dialog_gps(Gps *gps);
 gboolean settings_dialog_osm(void);
+gboolean settings_dialog_hardkeys(void);
+gboolean settings_dialog_colors(void);
 void update_gcs(void);
 
 #endif
